@@ -12,19 +12,19 @@ import (
 func TestActionsConfig(t *testing.T) {
 	cfg := &ActionsConfig{}
 	cfg.DisableWorkflow("test1.yaml")
-	assert.EqualValues(t, []string{"test1.yaml"}, cfg.DisabledWorkflows)
+	assert.Equal(t, []string{"test1.yaml"}, cfg.DisabledWorkflows)
 
 	cfg.DisableWorkflow("test1.yaml")
-	assert.EqualValues(t, []string{"test1.yaml"}, cfg.DisabledWorkflows)
+	assert.Equal(t, []string{"test1.yaml"}, cfg.DisabledWorkflows)
 
 	cfg.EnableWorkflow("test1.yaml")
-	assert.EqualValues(t, []string{}, cfg.DisabledWorkflows)
+	assert.Equal(t, []string{}, cfg.DisabledWorkflows)
 
 	cfg.EnableWorkflow("test1.yaml")
-	assert.EqualValues(t, []string{}, cfg.DisabledWorkflows)
+	assert.Equal(t, []string{}, cfg.DisabledWorkflows)
 
 	cfg.DisableWorkflow("test1.yaml")
 	cfg.DisableWorkflow("test2.yaml")
 	cfg.DisableWorkflow("test3.yaml")
-	assert.EqualValues(t, "test1.yaml,test2.yaml,test3.yaml", cfg.ToString())
+	assert.Equal(t, "test1.yaml,test2.yaml,test3.yaml", cfg.ToString())
 }
