@@ -4,7 +4,6 @@
 package stats
 
 import (
-	"context"
 	"testing"
 	"time"
 
@@ -40,7 +39,7 @@ func TestRepoStatsIndex(t *testing.T) {
 	err = UpdateRepoIndexer(repo)
 	assert.NoError(t, err)
 
-	assert.NoError(t, queue.GetManager().FlushAll(context.Background(), 5*time.Second))
+	assert.NoError(t, queue.GetManager().FlushAll(t.Context(), 5*time.Second))
 
 	status, err := repo_model.GetIndexerStatus(db.DefaultContext, repo, repo_model.RepoIndexerTypeStats)
 	assert.NoError(t, err)
