@@ -20,15 +20,14 @@ type Email struct {
 // It accepts a list of usernames.
 // If DB contains these users it will send the email to them.
 // If to list == nil, it's supposed to send emails to every user present in DB
-func SendEmail(ctx context.Context, subject, message string, to []string) (string, ResponseExtra) {
+func SendEmail(ctx context.Context, subject, message string, to []string) (*ResponseText, ResponseExtra) {
 	reqURL := setting.LocalURL + "api/internal/mail/send"
 
-	req := newInternalRequest(ctx, reqURL, "POST", Email{
+	req := newInternalRequestAPI(ctx, reqURL, "POST", Email{
 		Subject: subject,
 		Message: message,
 		To:      to,
 	})
 
-	resp, extra := requestJSONResp(req, &responseText{})
-	return resp.Text, extra
+	return requestJSONResp(req, &ResponseText{})
 }
