@@ -60,7 +60,7 @@ func TestExpandVars(t *testing.T) {
 	for _, kase := range kases {
 		t.Run(kase.tmpl, func(t *testing.T) {
 			res, err := Expand(kase.tmpl, kase.data)
-			assert.EqualValues(t, kase.out, res)
+			assert.Equal(t, kase.out, res)
 			if kase.error {
 				assert.Error(t, err)
 			} else {
