@@ -4,8 +4,8 @@
 package install
 
 import (
+	"net/http"
 	"net/http/httptest"
-	"path/filepath"
 	"testing"
 
 	"code.gitea.io/gitea/models/unittest"
@@ -18,24 +18,22 @@ func TestRoutes(t *testing.T) {
 	assert.NotNil(t, r)
 
 	w := httptest.NewRecorder()
-	req := httptest.NewRequest("GET", "/", nil)
+	req := httptest.NewRequest(http.MethodGet, "/", nil)
 	r.ServeHTTP(w, req)
-	assert.EqualValues(t, 200, w.Code)
+	assert.Equal(t, 200, w.Code)
 	assert.Contains(t, w.Body.String(), `class="page-content install"`)
 
 	w = httptest.NewRecorder()
-	req = httptest.NewRequest("GET", "/no-such", nil)
+	req = httptest.NewRequest(http.MethodGet, "/no-such", nil)
 	r.ServeHTTP(w, req)
-	assert.EqualValues(t, 404, w.Code)
+	assert.Equal(t, 404, w.Code)
 
 	w = httptest.NewRecorder()
-	req = httptest.NewRequest("GET", "/assets/img/gitea.svg", nil)
+	req = httptest.NewRequest(http.MethodGet, "/assets/img/gitea.svg", nil)
 	r.ServeHTTP(w, req)
-	assert.EqualValues(t, 200, w.Code)
+	assert.Equal(t, 200, w.Code)
 }
 
 func TestMain(m *testing.M) {
-	unittest.MainTest(m, &unittest.TestOptions{
-		GiteaRootPath: filepath.Join("..", ".."),
-	})
+	unittest.MainTest(m)
 }
