@@ -7,15 +7,15 @@ package admin
 import (
 	"code.gitea.io/gitea/models/db"
 	user_model "code.gitea.io/gitea/models/user"
-	"code.gitea.io/gitea/modules/base"
-	"code.gitea.io/gitea/modules/context"
 	"code.gitea.io/gitea/modules/setting"
 	"code.gitea.io/gitea/modules/structs"
+	"code.gitea.io/gitea/modules/templates"
 	"code.gitea.io/gitea/routers/web/explore"
+	"code.gitea.io/gitea/services/context"
 )
 
 const (
-	tplOrgs base.TplName = "admin/org/list"
+	tplOrgs templates.TplName = "admin/org/list"
 )
 
 // Organizations show all the organizations
@@ -24,12 +24,13 @@ func Organizations(ctx *context.Context) {
 	ctx.Data["PageIsAdminOrganizations"] = true
 
 	if ctx.FormString("sort") == "" {
-		ctx.SetFormString("sort", explore.UserSearchDefaultAdminSort)
+		ctx.SetFormString("sort", UserSearchDefaultAdminSort)
 	}
 
 	explore.RenderUserSearch(ctx, &user_model.SearchUserOptions{
-		Actor: ctx.Doer,
-		Type:  user_model.UserTypeOrganization,
+		Actor:           ctx.Doer,
+		Type:            user_model.UserTypeOrganization,
+		IncludeReserved: true, // administrator needs to list all accounts include reserved
 		ListOptions: db.ListOptions{
 			PageSize: setting.UI.Admin.OrgPagingNum,
 		},
