@@ -10,10 +10,10 @@ import (
 )
 
 func TestToCorrectPageSize(t *testing.T) {
-	assert.EqualValues(t, 30, ToCorrectPageSize(0))
-	assert.EqualValues(t, 30, ToCorrectPageSize(-10))
-	assert.EqualValues(t, 20, ToCorrectPageSize(20))
-	assert.EqualValues(t, 50, ToCorrectPageSize(100))
+	assert.Equal(t, 30, ToCorrectPageSize(0))
+	assert.Equal(t, 30, ToCorrectPageSize(-10))
+	assert.Equal(t, 20, ToCorrectPageSize(20))
+	assert.Equal(t, 50, ToCorrectPageSize(100))
 }
 
 func TestToGitServiceType(t *testing.T) {
@@ -21,6 +21,8 @@ func TestToGitServiceType(t *testing.T) {
 		typ  string
 		enum int
 	}{{
+		typ: "trash", enum: 1,
+	}, {
 		typ: "github", enum: 2,
 	}, {
 		typ: "gitea", enum: 3,
@@ -29,7 +31,13 @@ func TestToGitServiceType(t *testing.T) {
 	}, {
 		typ: "gogs", enum: 5,
 	}, {
-		typ: "trash", enum: 1,
+		typ: "onedev", enum: 6,
+	}, {
+		typ: "gitbucket", enum: 7,
+	}, {
+		typ: "codebase", enum: 8,
+	}, {
+		typ: "codecommit", enum: 9,
 	}}
 	for _, test := range tc {
 		assert.EqualValues(t, test.enum, ToGitServiceType(test.typ))
