@@ -91,18 +91,18 @@ func uploadConanPackageV1(t *testing.T, baseURL, token, name, version, user, cha
 		AddTokenAuth(token)
 	MakeRequest(t, req, http.StatusNotFound)
 
-	req = NewRequest(t, "GET", fmt.Sprintf("%s/digest", recipeURL)).
+	req = NewRequest(t, "GET", recipeURL+"/digest").
 		AddTokenAuth(token)
 	MakeRequest(t, req, http.StatusNotFound)
 
-	req = NewRequest(t, "GET", fmt.Sprintf("%s/download_urls", recipeURL)).
+	req = NewRequest(t, "GET", recipeURL+"/download_urls").
 		AddTokenAuth(token)
 	MakeRequest(t, req, http.StatusNotFound)
 
-	req = NewRequest(t, "POST", fmt.Sprintf("%s/upload_urls", recipeURL))
+	req = NewRequest(t, "POST", recipeURL+"/upload_urls")
 	MakeRequest(t, req, http.StatusUnauthorized)
 
-	req = NewRequestWithJSON(t, "POST", fmt.Sprintf("%s/upload_urls", recipeURL), map[string]int64{
+	req = NewRequestWithJSON(t, "POST", recipeURL+"/upload_urls", map[string]int64{
 		conanfileName: int64(len(contentConanfile)),
 		"removed.txt": 0,
 	}).AddTokenAuth(token)
@@ -127,18 +127,18 @@ func uploadConanPackageV1(t *testing.T, baseURL, token, name, version, user, cha
 		AddTokenAuth(token)
 	MakeRequest(t, req, http.StatusNotFound)
 
-	req = NewRequest(t, "GET", fmt.Sprintf("%s/digest", packageURL)).
+	req = NewRequest(t, "GET", packageURL+"/digest").
 		AddTokenAuth(token)
 	MakeRequest(t, req, http.StatusNotFound)
 
-	req = NewRequest(t, "GET", fmt.Sprintf("%s/download_urls", packageURL)).
+	req = NewRequest(t, "GET", packageURL+"/download_urls").
 		AddTokenAuth(token)
 	MakeRequest(t, req, http.StatusNotFound)
 
-	req = NewRequest(t, "POST", fmt.Sprintf("%s/upload_urls", packageURL))
+	req = NewRequest(t, "POST", packageURL+"/upload_urls")
 	MakeRequest(t, req, http.StatusUnauthorized)
 
-	req = NewRequestWithJSON(t, "POST", fmt.Sprintf("%s/upload_urls", packageURL), map[string]int64{
+	req = NewRequestWithJSON(t, "POST", packageURL+"/upload_urls", map[string]int64{
 		conaninfoName: int64(len(contentConaninfo)),
 		"removed.txt": 0,
 	}).AddTokenAuth(token)
@@ -167,7 +167,7 @@ func uploadConanPackageV2(t *testing.T, baseURL, token, name, version, user, cha
 		AddTokenAuth(token)
 	MakeRequest(t, req, http.StatusCreated)
 
-	req = NewRequest(t, "GET", fmt.Sprintf("%s/files", recipeURL)).
+	req = NewRequest(t, "GET", recipeURL+"/files").
 		AddTokenAuth(token)
 	resp := MakeRequest(t, req, http.StatusOK)
 
@@ -180,7 +180,7 @@ func uploadConanPackageV2(t *testing.T, baseURL, token, name, version, user, cha
 
 	packageURL := fmt.Sprintf("%s/packages/%s/revisions/%s", recipeURL, conanPackageReference, packageRevision)
 
-	req = NewRequest(t, "GET", fmt.Sprintf("%s/files", packageURL)).
+	req = NewRequest(t, "GET", packageURL+"/files").
 		AddTokenAuth(token)
 	MakeRequest(t, req, http.StatusNotFound)
 
@@ -188,7 +188,7 @@ func uploadConanPackageV2(t *testing.T, baseURL, token, name, version, user, cha
 		AddTokenAuth(token)
 	MakeRequest(t, req, http.StatusCreated)
 
-	req = NewRequest(t, "GET", fmt.Sprintf("%s/files", packageURL)).
+	req = NewRequest(t, "GET", packageURL+"/files").
 		AddTokenAuth(token)
 	resp = MakeRequest(t, req, http.StatusOK)
 
@@ -219,7 +219,7 @@ func TestPackageConan(t *testing.T) {
 		t.Run("Ping", func(t *testing.T) {
 			defer tests.PrintCurrentTest(t)()
 
-			req := NewRequest(t, "GET", fmt.Sprintf("%s/v1/ping", url))
+			req := NewRequest(t, "GET", url+"/v1/ping")
 			resp := MakeRequest(t, req, http.StatusOK)
 
 			assert.Equal(t, "revisions", resp.Header().Get("X-Conan-Server-Capabilities"))
@@ -230,7 +230,7 @@ func TestPackageConan(t *testing.T) {
 		t.Run("UserName/Password Authenticate", func(t *testing.T) {
 			defer tests.PrintCurrentTest(t)()
 
-			req := NewRequest(t, "GET", fmt.Sprintf("%s/v1/users/authenticate", url)).
+			req := NewRequest(t, "GET", url+"/v1/users/authenticate").
 				AddBasicAuth(user.Name)
 			resp := MakeRequest(t, req, http.StatusOK)
 
@@ -256,7 +256,7 @@ func TestPackageConan(t *testing.T) {
 
 				token := getTokenForLoggedInUser(t, session, scope)
 
-				req := NewRequest(t, "GET", fmt.Sprintf("%s/v1/users/authenticate", url)).
+				req := NewRequest(t, "GET", url+"/v1/users/authenticate").
 					AddTokenAuth(token)
 				resp := MakeRequest(t, req, expectedAuthStatusCode)
 				if expectedAuthStatusCode != http.StatusOK {
@@ -273,7 +273,7 @@ func TestPackageConan(t *testing.T) {
 
 				recipeURL := fmt.Sprintf("%s/v1/conans/%s/%s/%s/%s", url, "TestScope", version1, "testing", channel1)
 
-				req = NewRequestWithJSON(t, "POST", fmt.Sprintf("%s/upload_urls", recipeURL), map[string]int64{
+				req = NewRequestWithJSON(t, "POST", recipeURL+"/upload_urls", map[string]int64{
 					conanfileName: 64,
 					"removed.txt": 0,
 				}).AddTokenAuth(token)
@@ -308,7 +308,7 @@ func TestPackageConan(t *testing.T) {
 		t.Run("CheckCredentials", func(t *testing.T) {
 			defer tests.PrintCurrentTest(t)()
 
-			req := NewRequest(t, "GET", fmt.Sprintf("%s/v1/users/check_credentials", url)).
+			req := NewRequest(t, "GET", url+"/v1/users/check_credentials").
 				AddTokenAuth(token)
 			MakeRequest(t, req, http.StatusOK)
 		})
@@ -356,7 +356,7 @@ func TestPackageConan(t *testing.T) {
 
 						assert.Equal(t, int64(len(contentConaninfo)), pb.Size)
 					} else {
-						assert.FailNow(t, "unknown file: %s", pf.Name)
+						assert.FailNow(t, "unknown file", "unknown file: %s", pf.Name)
 					}
 				}
 			})
@@ -376,14 +376,14 @@ func TestPackageConan(t *testing.T) {
 			assert.Contains(t, fileHashes, conanfileName)
 			assert.Equal(t, "7abc52241c22090782c54731371847a8", fileHashes[conanfileName])
 
-			req = NewRequest(t, "GET", fmt.Sprintf("%s/digest", recipeURL))
+			req = NewRequest(t, "GET", recipeURL+"/digest")
 			resp = MakeRequest(t, req, http.StatusOK)
 
 			downloadURLs := make(map[string]string)
 			DecodeJSON(t, resp, &downloadURLs)
 			assert.Contains(t, downloadURLs, conanfileName)
 
-			req = NewRequest(t, "GET", fmt.Sprintf("%s/download_urls", recipeURL))
+			req = NewRequest(t, "GET", recipeURL+"/download_urls")
 			resp = MakeRequest(t, req, http.StatusOK)
 
 			DecodeJSON(t, resp, &downloadURLs)
@@ -404,14 +404,14 @@ func TestPackageConan(t *testing.T) {
 			assert.Contains(t, fileHashes, conaninfoName)
 			assert.Equal(t, "7628bfcc5b17f1470c468621a78df394", fileHashes[conaninfoName])
 
-			req = NewRequest(t, "GET", fmt.Sprintf("%s/digest", packageURL))
+			req = NewRequest(t, "GET", packageURL+"/digest")
 			resp = MakeRequest(t, req, http.StatusOK)
 
 			downloadURLs = make(map[string]string)
 			DecodeJSON(t, resp, &downloadURLs)
 			assert.Contains(t, downloadURLs, conaninfoName)
 
-			req = NewRequest(t, "GET", fmt.Sprintf("%s/download_urls", packageURL))
+			req = NewRequest(t, "GET", packageURL+"/download_urls")
 			resp = MakeRequest(t, req, http.StatusOK)
 
 			DecodeJSON(t, resp, &downloadURLs)
@@ -550,7 +550,7 @@ func TestPackageConan(t *testing.T) {
 		t.Run("Ping", func(t *testing.T) {
 			defer tests.PrintCurrentTest(t)()
 
-			req := NewRequest(t, "GET", fmt.Sprintf("%s/v2/ping", url))
+			req := NewRequest(t, "GET", url+"/v2/ping")
 			resp := MakeRequest(t, req, http.StatusOK)
 
 			assert.Equal(t, "revisions", resp.Header().Get("X-Conan-Server-Capabilities"))
@@ -561,7 +561,7 @@ func TestPackageConan(t *testing.T) {
 		t.Run("UserName/Password Authenticate", func(t *testing.T) {
 			defer tests.PrintCurrentTest(t)()
 
-			req := NewRequest(t, "GET", fmt.Sprintf("%s/v2/users/authenticate", url)).
+			req := NewRequest(t, "GET", url+"/v2/users/authenticate").
 				AddBasicAuth(user.Name)
 			resp := MakeRequest(t, req, http.StatusOK)
 
@@ -573,7 +573,7 @@ func TestPackageConan(t *testing.T) {
 			assert.Equal(t, user.ID, pkgMeta.UserID)
 			assert.Equal(t, auth_model.AccessTokenScopeAll, pkgMeta.Scope)
 
-			token = fmt.Sprintf("Bearer %s", body)
+			token = "Bearer " + body
 		})
 
 		badToken := ""
@@ -590,7 +590,7 @@ func TestPackageConan(t *testing.T) {
 
 				token := getTokenForLoggedInUser(t, session, scope)
 
-				req := NewRequest(t, "GET", fmt.Sprintf("%s/v2/users/authenticate", url)).
+				req := NewRequest(t, "GET", url+"/v2/users/authenticate").
 					AddTokenAuth(token)
 				resp := MakeRequest(t, req, expectedAuthStatusCode)
 				if expectedAuthStatusCode != http.StatusOK {
@@ -640,7 +640,7 @@ func TestPackageConan(t *testing.T) {
 		t.Run("CheckCredentials", func(t *testing.T) {
 			defer tests.PrintCurrentTest(t)()
 
-			req := NewRequest(t, "GET", fmt.Sprintf("%s/v2/users/check_credentials", url)).
+			req := NewRequest(t, "GET", url+"/v2/users/check_credentials").
 				AddTokenAuth(token)
 			MakeRequest(t, req, http.StatusOK)
 		})
@@ -664,7 +664,7 @@ func TestPackageConan(t *testing.T) {
 
 			recipeURL := fmt.Sprintf("%s/v2/conans/%s/%s/%s/%s", url, name, version1, user1, channel1)
 
-			req := NewRequest(t, "GET", fmt.Sprintf("%s/latest", recipeURL))
+			req := NewRequest(t, "GET", recipeURL+"/latest")
 			resp := MakeRequest(t, req, http.StatusOK)
 
 			obj := make(map[string]string)
