@@ -4,11 +4,11 @@
 package integration
 
 import (
-	"bytes"
 	"fmt"
 	"io"
 	"net/http"
 	"net/url"
+	"strings"
 	"testing"
 
 	auth_model "code.gitea.io/gitea/models/auth"
@@ -42,8 +42,8 @@ func TestAPIRepoBranchesPlain(t *testing.T) {
 		var branches []*api.Branch
 		assert.NoError(t, json.Unmarshal(bs, &branches))
 		assert.Len(t, branches, 2)
-		assert.EqualValues(t, "test_branch", branches[0].Name)
-		assert.EqualValues(t, "master", branches[1].Name)
+		assert.Equal(t, "test_branch", branches[0].Name)
+		assert.Equal(t, "master", branches[1].Name)
 
 		link2, _ := url.Parse(fmt.Sprintf("/api/v1/repos/org3/%s/branches/test_branch", repo3.Name))
 		MakeRequest(t, NewRequest(t, "GET", link2.String()).AddTokenAuth(publicOnlyToken), http.StatusForbidden)
@@ -53,20 +53,20 @@ func TestAPIRepoBranchesPlain(t *testing.T) {
 		assert.NoError(t, err)
 		var branch api.Branch
 		assert.NoError(t, json.Unmarshal(bs, &branch))
-		assert.EqualValues(t, "test_branch", branch.Name)
+		assert.Equal(t, "test_branch", branch.Name)
 
 		MakeRequest(t, NewRequest(t, "POST", link.String()).AddTokenAuth(publicOnlyToken), http.StatusForbidden)
 
 		req := NewRequest(t, "POST", link.String()).AddTokenAuth(token)
 		req.Header.Add("Content-Type", "application/json")
-		req.Body = io.NopCloser(bytes.NewBufferString(`{"new_branch_name":"test_branch2", "old_branch_name": "test_branch", "old_ref_name":"refs/heads/test_branch"}`))
+		req.Body = io.NopCloser(strings.NewReader(`{"new_branch_name":"test_branch2", "old_branch_name": "test_branch", "old_ref_name":"refs/heads/test_branch"}`))
 		resp = MakeRequest(t, req, http.StatusCreated)
 		bs, err = io.ReadAll(resp.Body)
 		assert.NoError(t, err)
 		var branch2 api.Branch
 		assert.NoError(t, json.Unmarshal(bs, &branch2))
-		assert.EqualValues(t, "test_branch2", branch2.Name)
-		assert.EqualValues(t, branch.Commit.ID, branch2.Commit.ID)
+		assert.Equal(t, "test_branch2", branch2.Name)
+		assert.Equal(t, branch.Commit.ID, branch2.Commit.ID)
 
 		resp = MakeRequest(t, NewRequest(t, "GET", link.String()).AddTokenAuth(token), http.StatusOK)
 		bs, err = io.ReadAll(resp.Body)
@@ -75,9 +75,9 @@ func TestAPIRepoBranchesPlain(t *testing.T) {
 		branches = []*api.Branch{}
 		assert.NoError(t, json.Unmarshal(bs, &branches))
 		assert.Len(t, branches, 3)
-		assert.EqualValues(t, "test_branch", branches[0].Name)
-		assert.EqualValues(t, "test_branch2", branches[1].Name)
-		assert.EqualValues(t, "master", branches[2].Name)
+		assert.Equal(t, "test_branch", branches[0].Name)
+		assert.Equal(t, "test_branch2", branches[1].Name)
+		assert.Equal(t, "master", branches[2].Name)
 
 		link3, _ := url.Parse(fmt.Sprintf("/api/v1/repos/org3/%s/branches/test_branch2", repo3.Name))
 		MakeRequest(t, NewRequest(t, "DELETE", link3.String()), http.StatusNotFound)
@@ -104,8 +104,8 @@ func TestAPIRepoBranchesMirror(t *testing.T) {
 	var branches []*api.Branch
 	assert.NoError(t, json.Unmarshal(bs, &branches))
 	assert.Len(t, branches, 2)
-	assert.EqualValues(t, "test_branch", branches[0].Name)
-	assert.EqualValues(t, "master", branches[1].Name)
+	assert.Equal(t, "test_branch", branches[0].Name)
+	assert.Equal(t, "master", branches[1].Name)
 
 	link2, _ := url.Parse(fmt.Sprintf("/api/v1/repos/org3/%s/branches/test_branch", repo5.Name))
 	resp = MakeRequest(t, NewRequest(t, "GET", link2.String()).AddTokenAuth(token), http.StatusOK)
@@ -113,18 +113,18 @@ func TestAPIRepoBranchesMirror(t *testing.T) {
 	assert.NoError(t, err)
 	var branch api.Branch
 	assert.NoError(t, json.Unmarshal(bs, &branch))
-	assert.EqualValues(t, "test_branch", branch.Name)
+	assert.Equal(t, "test_branch", branch.Name)
 
 	req := NewRequest(t, "POST", link.String()).AddTokenAuth(token)
 	req.Header.Add("Content-Type", "application/json")
-	req.Body = io.NopCloser(bytes.NewBufferString(`{"new_branch_name":"test_branch2", "old_branch_name": "test_branch", "old_ref_name":"refs/heads/test_branch"}`))
+	req.Body = io.NopCloser(strings.NewReader(`{"new_branch_name":"test_branch2", "old_branch_name": "test_branch", "old_ref_name":"refs/heads/test_branch"}`))
 	resp = MakeRequest(t, req, http.StatusForbidden)
 	bs, err = io.ReadAll(resp.Body)
 	assert.NoError(t, err)
-	assert.EqualValues(t, "{\"message\":\"Git Repository is a mirror.\",\"url\":\""+setting.AppURL+"api/swagger\"}\n", string(bs))
+	assert.Equal(t, "{\"message\":\"Git Repository is a mirror.\",\"url\":\""+setting.AppURL+"api/swagger\"}\n", string(bs))
 
 	resp = MakeRequest(t, NewRequest(t, "DELETE", link2.String()).AddTokenAuth(token), http.StatusForbidden)
 	bs, err = io.ReadAll(resp.Body)
 	assert.NoError(t, err)
-	assert.EqualValues(t, "{\"message\":\"Git Repository is a mirror.\",\"url\":\""+setting.AppURL+"api/swagger\"}\n", string(bs))
+	assert.Equal(t, "{\"message\":\"Git Repository is a mirror.\",\"url\":\""+setting.AppURL+"api/swagger\"}\n", string(bs))
 }
