@@ -4,7 +4,6 @@
 package integration
 
 import (
-	"context"
 	"net/http"
 	"net/url"
 	"strings"
@@ -27,7 +26,7 @@ func TestRepoActivity(t *testing.T) {
 		testEditFile(t, session, "user1", "repo1", "master", "README.md", "Hello, World (Edited)\n")
 		resp := testPullCreate(t, session, "user1", "repo1", false, "master", "master", "This is a pull title")
 		elem := strings.Split(test.RedirectURL(resp), "/")
-		assert.EqualValues(t, "pulls", elem[3])
+		assert.Equal(t, "pulls", elem[3])
 		testPullMerge(t, session, elem[1], elem[2], elem[4], repo_model.MergeStyleMerge, false)
 
 		testEditFileToNewBranch(t, session, "user1", "repo1", "master", "feat/better_readme", "README.md", "Hello, World (Edited Again)\n")
@@ -68,7 +67,7 @@ func TestRepoActivity(t *testing.T) {
 		// Non-existing default branch
 		repo1 := unittest.AssertExistsAndLoadBean(t, &repo_model.Repository{Name: "repo1"})
 		repo1.DefaultBranch = "no-such-branch"
-		_, _ = db.GetEngine(context.Background()).Cols("default_branch").Update(repo1)
+		_, _ = db.GetEngine(t.Context()).Cols("default_branch").Update(repo1)
 		req = NewRequest(t, "GET", "/user2/repo1/activity")
 		req.Header.Add("Accept", "text/html")
 		resp = session.MakeRequest(t, req, http.StatusNotFound)
