@@ -42,8 +42,8 @@ func testViewTimetrackingControls(t *testing.T, session *TestSession, user, repo
 
 	htmlDoc := NewHTMLParser(t, resp.Body)
 
-	htmlDoc.AssertElement(t, ".issue-start-time", canTrackTime)
-	htmlDoc.AssertElement(t, ".issue-add-time", canTrackTime)
+	AssertHTMLElement(t, htmlDoc, ".issue-start-time", canTrackTime)
+	AssertHTMLElement(t, htmlDoc, ".issue-add-time", canTrackTime)
 
 	issueLink := path.Join(user, repo, "issues", issue)
 	req = NewRequestWithValues(t, "POST", path.Join(issueLink, "times", "stopwatch", "toggle"), map[string]string{
@@ -59,8 +59,8 @@ func testViewTimetrackingControls(t *testing.T, session *TestSession, user, repo
 		events := htmlDoc.doc.Find(".event > span.text")
 		assert.Contains(t, events.Last().Text(), "started working")
 
-		htmlDoc.AssertElement(t, ".issue-stop-time", true)
-		htmlDoc.AssertElement(t, ".issue-cancel-time", true)
+		AssertHTMLElement(t, htmlDoc, ".issue-stop-time", true)
+		AssertHTMLElement(t, htmlDoc, ".issue-cancel-time", true)
 
 		// Sleep for 1 second to not get wrong order for stopping timer
 		time.Sleep(time.Second)
